pub(crate) struct Args {
pub(crate) config: Option<PathBuf>,
pub(crate) llama_url: Option<String>,
pub(crate) searxng_url: Option<String>,
pub(crate) system: Vec<PathBuf>,
pub(crate) debug: bool,
pub(crate) log_file: Option<PathBuf>,
pub(crate) tasks: Option<PathBuf>,
pub(crate) worklogs: Option<PathBuf>,
pub(crate) markdown_output: Option<PathBuf>,
pub(crate) knowledge: Option<PathBuf>,
pub(crate) session_logs: Option<PathBuf>,
pub(crate) resume: Option<Resume>,
}Expand description
Command-line arguments for WorkBuddy
Fields
config: Option<PathBuf>Config file path (containing base values for all of these arguments)
llama_url: Option<String>llama.cpp server base URL [default: http://127.0.0.1:8080]
searxng_url: Option<String>Base URL of a SearXNG instance for the web_search tool [default: http://127.0.0.1:8888]
system: Vec<PathBuf>Path to a file containing the system prompt. May be repeated; the
files are concatenated in the order given, separated by a blank line.
In a config file, system may be a single path (legacy) or a list
of paths.
debug: boolEnable debug-level logging
log_file: Option<PathBuf>File to append log output to, because the terminal is taken by the UI [default: $TMPDIR/work-buddy.log]
tasks: Option<PathBuf>Task file path
worklogs: Option<PathBuf>Directory to store work logs in
markdown_output: Option<PathBuf>Allow the LLM to create markdown files in this directory
knowledge: Option<PathBuf>JSON knowledge file to explain keywords (e.g. projects) and such
session_logs: Option<PathBuf>Where to store the raw session log for later resuming
resume: Option<Resume>Raw session log to resume from. With no value, resumes the newest session log in
--session-logs. A bare file name (no directory part) that is not in the current
directory is looked up in --session-logs, trying <name>.jsonl if the name has no
extension